@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.1305';
+our $VERSION = '0.1306';
 
 use Moo;
 use strictures 2;
@@ -169,12 +169,13 @@ sub draw {
 
     my $SPACE = $self->size;
 
+    my $frets = $self->frets + 1;
     my $font;
 
     # Setup a new image
     my $i = Imager->new(
         xsize => $SPACE + $self->strings * $SPACE,
-        ysize => $SPACE + $self->frets * $SPACE,
+        ysize => $SPACE + $frets * $SPACE,
     );
     $i->box( filled => 1, color => WHITE );
 
@@ -186,7 +187,7 @@ sub draw {
     }
 
     # Draw the horizontal fret lines
-    for my $fret ( 0 .. $self->frets - 1 ) {
+    for my $fret ( 0 .. $frets - 1 ) {
         $i->line(
             color => $self->fret_color,
             x1    => $SPACE,
@@ -216,7 +217,7 @@ sub draw {
                 r     => $SPACE / 8,
                 x     => $SPACE * $self->strings / 2 + $SPACE / 2,
                 y     => $SPACE + $fret * $SPACE + $SPACE / 2,
-            ) if ( $SPACE + $fret * $SPACE + $SPACE / 2 ) < ( $SPACE * $self->frets );
+            ) if ( $SPACE + $fret * $SPACE + $SPACE / 2 ) < ( $SPACE * $frets );
         }
     }
 
@@ -227,7 +228,7 @@ sub draw {
             x1    => $SPACE + $string * $SPACE,
             y1    => $SPACE,
             x2    => $SPACE + $string * $SPACE,
-            y2    => $SPACE + ($self->frets - 1) * $SPACE,
+            y2    => $SPACE + ($frets - 1) * $SPACE,
             aa    => 1,
             endp  => 1
         );
@@ -290,7 +291,7 @@ sub draw {
                     r     => $SPACE / 5,
                     x     => $SPACE + ($self->strings - $string) * $SPACE,
                     y     => $y,
-                ) if $y < $SPACE * $self->frets;
+                ) if $y < $SPACE * $frets;
             }
 
             # Decrement the current string number
@@ -306,7 +307,7 @@ sub draw {
                 text  => $chord_name,
                 color => BLACK,
                 x     => $SPACE,
-                y     => ($self->frets + 1) * $SPACE - $SPACE / 3,
+                y     => ($frets + 1) * $SPACE - $SPACE / 3,
                 size  => $SPACE / 2,
                 aa    => 1,
             );
@@ -326,12 +327,13 @@ sub _draw_horiz {
 
     my $SPACE = $self->size;
 
+    my $frets = $self->frets + 1;
     my $font;
 
     # Setup a new image
     my $i = Imager->new(
         ysize => $SPACE + $self->strings * $SPACE,
-        xsize => $SPACE + $self->frets * $SPACE,
+        xsize => $SPACE + $frets * $SPACE,
     );
     $i->box( filled => 1, color => WHITE );
 
@@ -343,7 +345,7 @@ sub _draw_horiz {
     }
 
     # Draw the vertical fret lines
-    for my $fret ( 0 .. $self->frets - 1 ) {
+    for my $fret ( 0 .. $frets - 1 ) {
         $i->line(
             color => $self->fret_color,
             y1    => $SPACE,
@@ -373,7 +375,7 @@ sub _draw_horiz {
                 r     => $SPACE / 8,
                 y     => $SPACE * $self->strings / 2 + $SPACE / 2,
                 x     => $SPACE + $fret * $SPACE + $SPACE / 2,
-            ) if ( $SPACE + $fret * $SPACE + $SPACE / 2 ) < ( $SPACE * $self->frets );
+            ) if ( $SPACE + $fret * $SPACE + $SPACE / 2 ) < ( $SPACE * $frets );
         }
     }
 
@@ -384,7 +386,7 @@ sub _draw_horiz {
             y1    => $SPACE + $string * $SPACE,
             x1    => $SPACE,
             y2    => $SPACE + $string * $SPACE,
-            x2    => $SPACE + ($self->frets - 1) * $SPACE,
+            x2    => $SPACE + ($frets - 1) * $SPACE,
             aa    => 1,
             endp  => 1
         );
@@ -447,7 +449,7 @@ sub _draw_horiz {
                     r     => $SPACE / 5,
                     x     => $x,
                     y     => $SPACE + ($string - 1) * $SPACE,
-                ) if $x < $SPACE * $self->frets;
+                ) if $x < $SPACE * $frets;
             }
 
             # Increment the current string number
@@ -528,7 +530,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.1305
+version 0.1306
 
 =head1 SYNOPSIS
 
@@ -538,8 +540,7 @@ version 0.1305
     chord    => 'xx0232',
     frets    => 5,     # the default
     position => 1,     # the default
-    font     => '/path/to/TTF/font.ttf',
-    outfile  => 'Dm',
+    outfile  => 'Dmajor',
     type     => 'png', # the default
   );
 
@@ -548,13 +549,15 @@ version 0.1305
     frets    => 13,
     absolute => 1,
     size     => 50, # relative units, not pixels
-    outfile  => 'fretboard',
     horiz    => 1,
+    showname => 'Em',
+    outfile  => 'fretboard',
+    font     => '/path/to/TTF/font.ttf',
     verbose  => 1,
   );
 
   $dia->chord('x02220');          # set a new chord
-  $dia->position(1);              # set a new position
+  $dia->position(7);              # set a new position
   $dia->outfile('mystery-chord'); # set a new filename
   $dia->showname('Xb dim');       # "X flat diminished"
 
@@ -586,13 +589,12 @@ specifications.
 
 For a chord string, non-zero digits represent frets, C<x> (or C<X>)
 indicates a muted string, C<0> (or C<o> or C<O>) indicates an open
-string, and a dash (C<->) means skip to the next string.  The default
-order of the strings is C<654321> from lowest to highest.
+string, and a dash (C<->) means skip to the next string.
 
 For an array-ref of chord specifications, the first element is the
 chord position, and the second is the chord string.
 
-Chord string examples:
+Chord string examples at position 1:
 
   C: x32010
   D: xx0232
@@ -602,18 +604,14 @@ Chord string examples:
   A: x02220
   B: x24442
 
-  Cm: xx5543
+  Cm: x3101x
   Dm: xx0231
   Em: 022000
-  Fm: xx3111
-  Gm: xx5333
   Am: x02210
-  Bm: x24432
 
   C7: x32310
   D7: xx0212
   E7: 020100
-  F7: xx1211
   G7: 320001
   A7: x02020
   B7: x21202
@@ -663,7 +661,7 @@ Default: C<5>
   $size = $dia->size;
 
 The relative size of the diagram.  The smallest visible diagram is
-B<size> = C<6>.
+B<size> = C<6>.  (This is B<not> a measure of pixels.)
 
 Default: C<30>
 
